======
Moccasin
======

.. toctree::
    :maxdepth: 2

    Overview <index.rst>

.. toctree::
    :caption: Getting Started
    :maxdepth: 2

    installing-moccasin.rst
    quickstart.rst

.. toctree::
    :caption: Project Overview
    :maxdepth: 2

    moccasin.toml <moccasin_toml.rst>
    project.rst 
    networks.rst
    dependencies.rst

.. toctree::
    :caption: Major Commands
    :maxdepth: 2

    wallet <wallet.rst>
    run <script.rst>
    test <testing.rst>
    console <console.rst>

.. toctree::
    :caption: Reference
    :maxdepth: 2

    cli_commands.rst
    all_moccasin_toml_parameters.rst
    common-errors.rst
